import sys
from argparse import ArgumentParser
from pyedev.commands.config import config_subparser, CONFIG_HELP
from pyedev.commands.build import build_subparser, BUILD_HELP

VERSION = (0, 6, 1)

DESC = "Python, CMake Embedded Development Tools for ARM Cortex."


def version():
    """Get version string."""
    assert len(VERSION) == 3
    return str(".".join([str(x) for x in VERSION]))

__version__ = version()


def console(args=None):
    """Run console and return code.

    Arguments:
        args (list): List of command line arguments.
    """
    # Script includes help and version options by default.
    p = ArgumentParser(description=DESC)
    p.add_argument("-v", "--version", action="version",
                   version=version())

    sp = p.add_subparsers()

    # --- START COMMANDS ---

    # Add config command and populate subparser.
    sp_config = sp.add_parser("config", help=CONFIG_HELP)
    config_subparser(sp_config)

    # Add build command and populate subparser.
    sp_config = sp.add_parser("build", help=BUILD_HELP)
    build_subparser(sp_config)

    # --- END COMMANDS ---

    # Parse command line arguments.
    args = p.parse_args(args=args)

    # If command function not defined, display usage and return.
    if not hasattr(args, "func"):
        p.print_usage()
        return int(0)
    else:
        code, message = args.func(args)

        # If message returned display it on stdout/stderr.
        if message:
            if code == 0:
                sys.stdout.write("{0}: {1}\n".format(p.prog, message))
            else:
                sys.stderr.write("{0}: {1}\n".format(p.prog, message))

        # Return exit code.
        return int(code)


def main(args=None):
    """Run console with system exit.

    Arguments:
        args (list): List of command line arguments.
    """
    sys.exit(console(args))
