
def akw(ik, ld, typ, default, invalid=[], valid=[], required=False):
    """Get and cast a value from argument list or keyword dictionary.

    Args:
        ik (int or str): Arguments list index or keyword dictionary key.
        ld (list or dict): Arguments list or keyword dictionary.
        typ (class): Type to cast variable value.
        default (any): Default variable value.

    Kwargs:
        invalid (list): List of invalid values.
        valid (list): List of valid values.
        required (bool): Variable is required.
    """
    # Sanity check and cast arguments to this function.
    if isinstance(ik, int):
        ld = list(ld)
    elif isinstance(ik, str):
        ld = dict(ld)
    else:
        estr = "Invalid argument type ({0})".format(type(ik))
        raise TypeError(estr)
    default = typ(default)
    invalid = list(invalid)
    valid = list(valid)
    required = bool(required)

    val = default
    # Get value from arguments.
    if isinstance(ik, int):
        if ik < len(ld):
            val = ld[ik]
        elif required:
            estr = "Too few arguments ({0}, {1})".format(ik, ld)
            raise IndexError(estr)
    elif isinstance(ik, str):
        if ik in ld:
            val = ld[ik]
        elif required:
            estr = "Missing keyword argument ({0}, {1})".format(ik, ld)
            raise KeyError(estr)

    # Do not cast strings into lists.
    if issubclass(typ, list) or issubclass(typ, tuple):
        if isinstance(val, str):
            estr = "Invalid argument type".format(type(val))
            raise TypeError(estr)

    # Cast value to type.
    val = typ(val)

    # Check if value is invalid.
    if len(invalid) > 0:
        if val in [typ(x) for x in invalid]:
            estr = "Argument value invalid ({0}, {1})".format(ik, val)
            raise ValueError(estr)

    # Check if value is valid.
    if len(valid) > 0:
        if val not in [typ(x) for x in valid]:
            estr = "Argument value not valid ({0}, {1})".format(ik, val)
            raise ValueError(estr)

    return val
