/* Memory area definitions. */
MEMORY
{
    FLASH (rx) : ORIGIN = 0x00000000, LENGTH = 1024K
    RAM  (rwx) : ORIGIN = 0x20000000, LENGTH = 256K
}

/* Output section definitions. */
SECTIONS
{
    . = ORIGIN(FLASH);

    /* Interrupt vector table. */
    .isr_vector_table :
    {
        . = ALIGN(4);
        KEEP(*(.isr_vector_table))
        . = ALIGN(4);
    } >FLASH

    /* User code section. */
    .text :
    {
        . = ALIGN(4);
        PROVIDE(__text_start = .);

        . = ALIGN(4);
        *(.text .text.* .gnu.linkonce.t.*)
        *(.glue_7t .glue_7)

        . = ALIGN(4);
        KEEP(*(.eh_frame_hdr))
        KEEP(*(.eh_frame))

        . = ALIGN(4);
        KEEP(*(.init))
        KEEP(*(.fini))

        . = ALIGN(4);
        PROVIDE(__text_end = .);
    } >FLASH

    /* Constant data section. */
    .rodata :
    {
        . = ALIGN(4);
        PROVIDE(__rodata_start = .);

        *(.rodata .rodata.* .gnu.linkonce.r.*)

        . = ALIGN(4);
        PROVIDE(__rodata_end = .);
    } >FLASH

    .ARM.extab :
    {
        . = ALIGN(4);

        *(.ARM.extab* .gnu.linkonce.armextab.*)

        . = ALIGN(4);
    } >FLASH

    .ARM :
    {
        . = ALIGN(4);
        PROVIDE(__exidx_start = .);

        *(.ARM.exidx* .gnu.linkonce.armexidx.*)

        . = ALIGN(4);
        PROVIDE(__exidx_end = .);
    } >FLASH

    .preinit_array :
    {
        PROVIDE_HIDDEN(__preinit_array_start = .);
        KEEP(*(.preinit_array*))
        PROVIDE_HIDDEN(__preinit_array_end = .);
    } >FLASH

    .init_array :
    {
        PROVIDE_HIDDEN(__init_array_start = .);
        KEEP(*(SORT(.init_array.*)))
        KEEP(*(.init_array*))
        PROVIDE_HIDDEN(__init_array_end = .);
    } >FLASH

    .fini_array :
    {
        PROVIDE_HIDDEN(__fini_array_start = .);
        KEEP(*(SORT(.fini_array.*)))
        KEEP(*(.fini_array*))
        PROVIDE_HIDDEN(__fini_array_end = .);
    } >FLASH

    /* Initialised data section. */
    .data :
    {
        . = ALIGN(4);
        PROVIDE(__data_start = .);

        *(.data .data.* .gnu.linkonce.d.*)

        . = ALIGN(4);
        PROVIDE(__data_end = .);
    } >RAM AT >FLASH

    /* Used by startup to initialise data section. */
    PROVIDE(__data_load = LOADADDR(.data));

    /* Uninitialised data section. */
    .bss :
    {
        . = ALIGN(4);
        PROVIDE(__bss_start = .);
        PROVIDE_HIDDEN(__bss_start__ = __bss_start);

        *(.bss .bss.* gnu.linkonce.b.*)
        *(COMMON)

        . = ALIGN(4);
        PROVIDE(__bss_end = .);
        PROVIDE_HIDDEN(__bss_end__ = __bss_end);
    } >RAM

    /* Heap located after of uninitialised data section. */
    . = ALIGN(4);
    PROVIDE(__heap = .);

    /* Descending stack. */
    . = ORIGIN(RAM) + LENGTH(RAM);
    . = ALIGN(4);
    PROVIDE(__stack = .);

    /* Remove information from standard libraries. */
    .ARM.attributes 0 :
    {
        *(.ARM.attributes)
    }

    /DISCARD/ :
    {
        libc.a ( * )
        libm.a ( * )
        libgcc.a ( * )
        *(.note.GNU-stack)
    }
}
