.syntax unified
.cpu cortex-m4
.arch armv7-m
.fpu softvfp
.thumb

.word __data_load
.word __data_start
.word __data_end
.word __bss_start
.word __bss_end
.word __stack

.section .text
.weak Reset_Handler
.type Reset_Handler, %function
Reset_Handler:
  ldr  sp, =__stack
  movs r1, #0
  b    LoopCopyDataInit

CopyDataInit:
  ldr  r3, =__data_load
  ldr  r3, [r3, r1]
  str  r3, [r0, r1]
  adds r1, r1, #4

LoopCopyDataInit:
  ldr  r0, =__data_start
  ldr  r3, =__data_end
  adds r2, r0, r1
  cmp  r2, r3
  bcc  CopyDataInit
  ldr  r2, =__bss_start
  b    LoopFillZerobss

FillZerobss:
  movs r3, #0
  str  r3, [r2], #4

LoopFillZerobss:
  ldr  r3, =__bss_end
  cmp  r2, r3
  bcc  FillZerobss

  ldr  r0, =0xE000ED88
  ldr  r1, [r0]
  orr  r1, r1, #(0xF << 20)
  str  r1, [r0]
  dsb
  isb

  bl   __libc_init_array
  bl   main
  bx   lr

.size Reset_Handler, .-Reset_Handler

.section .text.Default_Handler,"ax",%progbits
Default_Handler:
Infinite_Loop:
  b Infinite_Loop

.size Default_Handler, .-Default_Handler

.section .isr_vector_table,"a",%progbits
.type    __isr_vector_table, %object
.size    __isr_vector_table, .-__isr_vector_table

__isr_vector_table:
  .word __stack
  .word Reset_Handler

  .word NMI_Handler
  .word HardFault_Handler
  .word MemManage_Handler
  .word BusFault_Handler
  .word UsageFault_Handler
  .word 0
  .word 0
  .word 0
  .word 0
  .word SVC_Handler
  .word DebugMon_Handler
  .word 0
  .word PendSV_Handler
  .word SysTick_Handler

  .word GPIOA_Handler           /* 0   */
  .word GPIOB_Handler           /* 1   */
  .word GPIOC_Handler           /* 2   */
  .word GPIOD_Handler           /* 3   */
  .word GPIOE_Handler           /* 4   */
  .word UART0_Handler           /* 5   */
  .word UART1_Handler           /* 6   */
  .word SSI0_Handler            /* 7   */
  .word I2C0_Handler            /* 8   */
  .word PWM0Fault_Handler       /* 9   */
  .word PWM0Gen0_Handler        /* 10  */
  .word PWM0Gen1_Handler        /* 11  */
  .word PWM0Gen2_Handler        /* 12  */
  .word QEI0_Handler            /* 13  */
  .word ADC0Seq0_Handler        /* 14  */
  .word ADC0Seq1_Handler        /* 15  */
  .word ADC0Seq2_Handler        /* 16  */
  .word ADC0Seq3_Handler        /* 17  */
  .word Watchdog_Handler        /* 18  */
  .word Timer0A_Handler         /* 19  */
  .word Timer0B_Handler         /* 20  */
  .word Timer1A_Handler         /* 21  */
  .word Timer1B_Handler         /* 22  */
  .word Timer2A_Handler         /* 23  */
  .word Timer2B_Handler         /* 24  */
  .word ACMP0_Handler           /* 25  */
  .word ACMP1_Handler           /* 26  */
  .word ACMP2_Handler           /* 27  */
  .word SysCtl_Handler          /* 28  */
  .word FlashCtl_Handler        /* 29  */
  .word GPIOF_Handler           /* 30  */
  .word GPIOG_Handler           /* 31  */
  .word GPIOH_Handler           /* 32  */
  .word UART2_Handler           /* 33  */
  .word SSI1_Handler            /* 34  */
  .word Timer3A_Handler         /* 35  */
  .word Timer3B_Handler         /* 36  */
  .word I2C1_Handler            /* 37  */
  .word CAN0_Handler            /* 38  */
  .word CAN1_Handler            /* 39  */
  .word Ethernet_Handler        /* 40  */
  .word Hibernate_Handler       /* 41  */
  .word USB_Handler             /* 42  */
  .word PWM0Gen3_Handler        /* 43  */
  .word uDMA_Handler            /* 44  */
  .word uDMAErr_Handler         /* 45  */
  .word ADC1Seq0_Handler        /* 46  */
  .word ADC1Seq1_Handler        /* 47  */
  .word ADC1Seq2_Handler        /* 48  */
  .word ADC1Seq3_Handler        /* 49  */
  .word EPI0_Handler            /* 50  */
  .word GPIOJ_Handler           /* 51  */
  .word GPIOK_Handler           /* 52  */
  .word GPIOL_Handler           /* 53  */
  .word SSI2_Handler            /* 54  */
  .word SSI3_Handler            /* 55  */
  .word UART3_Handler           /* 56  */
  .word UART4_Handler           /* 57  */
  .word UART5_Handler           /* 58  */
  .word UART6_Handler           /* 59  */
  .word UART7_Handler           /* 60  */
  .word I2C2_Handler            /* 61  */
  .word I2C3_Handler            /* 62  */
  .word Timer4A_Handler         /* 63  */
  .word Timer4B_Handler         /* 64  */
  .word Timer5A_Handler         /* 65  */
  .word Timer5B_Handler         /* 66  */
  .word SysExc_Handler          /* 67  */
  .word 0                       /* 68  */
  .word 0                       /* 69  */
  .word I2C4_Handler            /* 70  */
  .word I2C5_Handler            /* 71  */
  .word GPIOM_Handler           /* 72  */
  .word GPION_Handler           /* 73  */
  .word 0                       /* 74  */
  .word Tamper_Handler          /* 75  */
  .word GPIOP_Handler           /* 76  */
  .word GPIOP1_Handler          /* 77  */
  .word GPIOP2_Handler          /* 78  */
  .word GPIOP3_Handler          /* 79  */
  .word GPIOP4_Handler          /* 80  */
  .word GPIOP5_Handler          /* 81  */
  .word GPIOP6_Handler          /* 82  */
  .word GPIOP7_Handler          /* 83  */
  .word GPIOQ_Handler           /* 84  */
  .word GPIOQ1_Handler          /* 85  */
  .word GPIOQ2_Handler          /* 86  */
  .word GPIOQ3_Handler          /* 87  */
  .word GPIOQ4_Handler          /* 88  */
  .word GPIOQ5_Handler          /* 89  */
  .word GPIOQ6_Handler          /* 90  */
  .word GPIOQ7_Handler          /* 91  */
  .word 0                       /* 92  */
  .word 0                       /* 93  */
  .word 0                       /* 94  */
  .word 0                       /* 95  */
  .word 0                       /* 96  */
  .word 0                       /* 97  */
  .word Timer6A_Handler         /* 98  */
  .word Timer6B_Handler         /* 99  */
  .word Timer7A_Handler         /* 100 */
  .word Timer7B_Handler         /* 101 */
  .word I2C6_Handler            /* 102 */
  .word I2C7_Handler            /* 103 */
  .word 0                       /* 104 */
  .word 0                       /* 105 */
  .word 0                       /* 106 */
  .word 0                       /* 107 */
  .word 0                       /* 108 */
  .word I2C8_Handler            /* 109 */
  .word I2C9_Handler            /* 110 */

.weak      NMI_Handler
.thumb_set NMI_Handler,Default_Handler

.weak      HardFault_Handler
.thumb_set HardFault_Handler,Default_Handler

.weak      MemManage_Handler
.thumb_set MemManage_Handler,Default_Handler

.weak      BusFault_Handler
.thumb_set BusFault_Handler,Default_Handler

.weak      UsageFault_Handler
.thumb_set UsageFault_Handler,Default_Handler

.weak      SVC_Handler
.thumb_set SVC_Handler,Default_Handler

.weak      DebugMon_Handler
.thumb_set DebugMon_Handler,Default_Handler

.weak      PendSV_Handler
.thumb_set PendSV_Handler,Default_Handler

.weak      SysTick_Handler
.thumb_set SysTick_Handler,Default_Handler

.weak      GPIOA_Handler
.thumb_set GPIOA_Handler,Default_Handler

.weak      GPIOB_Handler
.thumb_set GPIOB_Handler,Default_Handler

.weak      GPIOC_Handler
.thumb_set GPIOC_Handler,Default_Handler

.weak      GPIOD_Handler
.thumb_set GPIOD_Handler,Default_Handler

.weak      GPIOE_Handler
.thumb_set GPIOE_Handler,Default_Handler

.weak      UART0_Handler
.thumb_set UART0_Handler,Default_Handler

.weak      UART1_Handler
.thumb_set UART1_Handler,Default_Handler

.weak      SSI0_Handler
.thumb_set SSI0_Handler,Default_Handler

.weak      I2C0_Handler
.thumb_set I2C0_Handler,Default_Handler

.weak      PWM0Fault_Handler
.thumb_set PWM0Fault_Handler,Default_Handler

.weak      PWM0Gen0_Handler
.thumb_set PWM0Gen0_Handler,Default_Handler

.weak      PWM0Gen1_Handler
.thumb_set PWM0Gen1_Handler,Default_Handler

.weak      PWM0Gen2_Handler
.thumb_set PWM0Gen2_Handler,Default_Handler

.weak      QEI0_Handler
.thumb_set QEI0_Handler,Default_Handler

.weak      ADC0Seq0_Handler
.thumb_set ADC0Seq0_Handler,Default_Handler

.weak      ADC0Seq1_Handler
.thumb_set ADC0Seq1_Handler,Default_Handler

.weak      ADC0Seq2_Handler
.thumb_set ADC0Seq2_Handler,Default_Handler

.weak      ADC0Seq3_Handler
.thumb_set ADC0Seq3_Handler,Default_Handler

.weak      Watchdog_Handler
.thumb_set Watchdog_Handler,Default_Handler

.weak      Timer0A_Handler
.thumb_set Timer0A_Handler,Default_Handler

.weak      Timer0B_Handler
.thumb_set Timer0B_Handler,Default_Handler

.weak      Timer1A_Handler
.thumb_set Timer1A_Handler,Default_Handler

.weak      Timer1B_Handler
.thumb_set Timer1B_Handler,Default_Handler

.weak      Timer2A_Handler
.thumb_set Timer2A_Handler,Default_Handler

.weak      Timer2B_Handler
.thumb_set Timer2B_Handler,Default_Handler

.weak      ACMP0_Handler
.thumb_set ACMP0_Handler,Default_Handler

.weak      ACMP1_Handler
.thumb_set ACMP1_Handler,Default_Handler

.weak      ACMP2_Handler
.thumb_set ACMP2_Handler,Default_Handler

.weak      SysCtl_Handler
.thumb_set SysCtl_Handler,Default_Handler

.weak      FlashCtl_Handler
.thumb_set FlashCtl_Handler,Default_Handler

.weak      GPIOF_Handler
.thumb_set GPIOF_Handler,Default_Handler

.weak      GPIOG_Handler
.thumb_set GPIOG_Handler,Default_Handler

.weak      GPIOH_Handler
.thumb_set GPIOH_Handler,Default_Handler

.weak      UART2_Handler
.thumb_set UART2_Handler,Default_Handler

.weak      SSI1_Handler
.thumb_set SSI1_Handler,Default_Handler

.weak      Timer3A_Handler
.thumb_set Timer3A_Handler,Default_Handler

.weak      Timer3B_Handler
.thumb_set Timer3B_Handler,Default_Handler

.weak      I2C1_Handler
.thumb_set I2C1_Handler,Default_Handler

.weak      CAN0_Handler
.thumb_set CAN0_Handler,Default_Handler

.weak      CAN1_Handler
.thumb_set CAN1_Handler,Default_Handler

.weak      Ethernet_Handler
.thumb_set Ethernet_Handler,Default_Handler

.weak      Hibernate_Handler
.thumb_set Hibernate_Handler,Default_Handler

.weak      USB_Handler
.thumb_set USB_Handler,Default_Handler

.weak      PWM0Gen3_Handler
.thumb_set PWM0Gen3_Handler,Default_Handler

.weak      uDMA_Handler
.thumb_set uDMA_Handler,Default_Handler

.weak      uDMAErr_Handler
.thumb_set uDMAErr_Handler,Default_Handler

.weak      ADC1Seq0_Handler
.thumb_set ADC1Seq0_Handler,Default_Handler

.weak      ADC1Seq1_Handler
.thumb_set ADC1Seq1_Handler,Default_Handler

.weak      ADC1Seq2_Handler
.thumb_set ADC1Seq2_Handler,Default_Handler

.weak      ADC1Seq3_Handler
.thumb_set ADC1Seq3_Handler,Default_Handler

.weak      EPI0_Handler
.thumb_set EPI0_Handler,Default_Handler

.weak      GPIOJ_Handler
.thumb_set GPIOJ_Handler,Default_Handler

.weak      GPIOK_Handler
.thumb_set GPIOK_Handler,Default_Handler

.weak      GPIOL_Handler
.thumb_set GPIOL_Handler,Default_Handler

.weak      SSI2_Handler
.thumb_set SSI2_Handler,Default_Handler

.weak      SSI3_Handler
.thumb_set SSI3_Handler,Default_Handler

.weak      UART3_Handler
.thumb_set UART3_Handler,Default_Handler

.weak      UART4_Handler
.thumb_set UART4_Handler,Default_Handler

.weak      UART5_Handler
.thumb_set UART5_Handler,Default_Handler

.weak      UART6_Handler
.thumb_set UART6_Handler,Default_Handler

.weak      UART7_Handler
.thumb_set UART7_Handler,Default_Handler

.weak      I2C2_Handler
.thumb_set I2C2_Handler,Default_Handler

.weak      I2C3_Handler
.thumb_set I2C3_Handler,Default_Handler

.weak      Timer4A_Handler
.thumb_set Timer4A_Handler,Default_Handler

.weak      Timer4B_Handler
.thumb_set Timer4B_Handler,Default_Handler

.weak      Timer5A_Handler
.thumb_set Timer5A_Handler,Default_Handler

.weak      Timer5B_Handler
.thumb_set Timer5B_Handler,Default_Handler

.weak      SysExc_Handler
.thumb_set SysExc_Handler,Default_Handler

.weak      I2C4_Handler
.thumb_set I2C4_Handler,Default_Handler

.weak      I2C5_Handler
.thumb_set I2C5_Handler,Default_Handler

.weak      GPIOM_Handler
.thumb_set GPIOM_Handler,Default_Handler

.weak      GPION_Handler
.thumb_set GPION_Handler,Default_Handler

.weak      Tamper_Handler
.thumb_set Tamper_Handler,Default_Handler

.weak      GPIOP_Handler
.thumb_set GPIOP_Handler,Default_Handler

.weak      GPIOP1_Handler
.thumb_set GPIOP1_Handler,Default_Handler

.weak      GPIOP2_Handler
.thumb_set GPIOP2_Handler,Default_Handler

.weak      GPIOP3_Handler
.thumb_set GPIOP3_Handler,Default_Handler

.weak      GPIOP4_Handler
.thumb_set GPIOP4_Handler,Default_Handler

.weak      GPIOP5_Handler
.thumb_set GPIOP5_Handler,Default_Handler

.weak      GPIOP6_Handler
.thumb_set GPIOP6_Handler,Default_Handler

.weak      GPIOP7_Handler
.thumb_set GPIOP7_Handler,Default_Handler

.weak      GPIOQ_Handler
.thumb_set GPIOQ_Handler,Default_Handler

.weak      GPIOQ1_Handler
.thumb_set GPIOQ1_Handler,Default_Handler

.weak      GPIOQ2_Handler
.thumb_set GPIOQ2_Handler,Default_Handler

.weak      GPIOQ3_Handler
.thumb_set GPIOQ3_Handler,Default_Handler

.weak      GPIOQ4_Handler
.thumb_set GPIOQ4_Handler,Default_Handler

.weak      GPIOQ5_Handler
.thumb_set GPIOQ5_Handler,Default_Handler

.weak      GPIOQ6_Handler
.thumb_set GPIOQ6_Handler,Default_Handler

.weak      GPIOQ7_Handler
.thumb_set GPIOQ7_Handler,Default_Handler

.weak      Timer6A_Handler
.thumb_set Timer6A_Handler,Default_Handler

.weak      Timer6B_Handler
.thumb_set Timer6B_Handler,Default_Handler

.weak      Timer7A_Handler
.thumb_set Timer7A_Handler,Default_Handler

.weak      Timer7B_Handler
.thumb_set Timer7B_Handler,Default_Handler

.weak      I2C6_Handler
.thumb_set I2C6_Handler,Default_Handler

.weak      I2C7_Handler
.thumb_set I2C7_Handler,Default_Handler

.weak      I2C8_Handler
.thumb_set I2C8_Handler,Default_Handler

.weak      I2C9_Handler
.thumb_set I2C9_Handler,Default_Handler
