from os import devnull
from unittest import TestCase
# Use check_call rather than run for Python 2.7 support.
from subprocess import check_call
from pyedev.commands import akw


class TestPyedevInstall(TestCase):

    def test_cmake(self):
        """Test CMake is installed"""
        self.assertTrue(_installed("cmake", ["--help"]), "CMake is not installed!")

    def test_make(self):
        """Test Make is installed"""
        self.assertTrue(_installed("make", ["-v"]), "Make is not installed!")


def _installed(*args):
    """Check that a program is installed using optional arguments.

    Args:
        prog (str): Program to attempt to invoke.
        args (list): Optional command line arguments.
    """
    prog = akw(0, args, str, None, invalid=("",), required=True)
    args = akw(1, args, list, [])

    with open(devnull, "w") as f:
        try:
            check_call([prog] + args, stdout=f, stderr=f)
        except:
            return False

        return True

    return False
